@@ -105,24 +105,28 @@ def create_parser():
   # Year
   year = Word(nums, exact=4)
   
-  # Starting date
-  first_date = Group(full_day_string("day") + Optional(month)("month") + Optional(year)("year"))
-  
-  # Ending date
-  last_date = Group(full_day_string("day") + month("month") + Optional(year)("year"))
-  
-  # Possible separators
-  separator = oneOf(u"- -- to until \u2013 \u2014")
-  
-  # Final putting together of everything
-  daterange = Optional(first_date("start") + separator.suppress()) + last_date("end") + stringEnd
-  
   time_sep = oneOf(": .")
-  am_pm = oneOf("AM am Am PM pm Pm")
+  am_pm = oneOf("am pm", caseless=True)
   hours = Word(nums, max=2)
   mins = Word(nums, max=2)
   
-  time = hours("hour") + Optional(time_sep).suppress() + mins("mins") + Optional(am_pm)("meridian")
+  time = hours("hour") + time_sep.suppress() + mins("mins") + Optional(am_pm)("meridian")
+  
+  # Starting date
+  first_date = Group(Optional(time).suppress() + full_day_string("day") + Optional(month)("month") + Optional(year)("year") + Optional(time).suppress())
+  
+  # Ending date
+  last_date = Group(Optional(time).suppress() + full_day_string("day") + month("month") + Optional(year)("year") + Optional(time).suppress())
+  
+  # Possible separators
+  separator = oneOf(u"- -- to until \u2013 \u2014 ->", caseless=True)
+  
+  # Strings to completely ignore (whitespace ignored by default)
+  ignoreable_chars = oneOf(", from", caseless=True)
+  
+  # Final putting together of everything
+  daterange = Optional(first_date("start") + separator.suppress()) + last_date("end") + stringEnd
+  daterange.ignore(ignoreable_chars)
 
   return daterange
 
